==> ws-v3.70.8-src.tar.gz: ws-v3.70-8/include/WSCgripHand.h <==
//
// Copyright (C) 1999-2004 Toshikaz Hirabayashi
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
// not be used in advertising or otherwise to promote the sale, use or other
// dealings in this Software without prior written authorization from
// Toshikaz Hirabayashi.

#ifndef WSCGRIPHAND_H
#define WSCGRIPHAND_H

#include <WScom.h>
#include <WSCform.h>
class WSDprivateTimer;
#define WS_GRIPH_HANDLER "G-HANDLER"
#define WS_GRIPH_SIZE 5

class WSCgripHand :public WSCform{

  protected:
    WSDprivateTimer* _update_timer;

    static void _grip_hand_update_proc(void*);

    long _device_initialize();
  public:
    WSCgripHand(WSCbase*,char*);
    virtual ~WSCgripHand();
    virtual long getObjectType();

    virtual void onMousePress(WSCpoint*);
    virtual void onMouseRelease(WSCpoint*);

    WSMFguiClassDef(WSCgripHand,WSCform);
};
extern WSDLEX WSCbase* WSGFgetNewGripHand(WSCbase* parent);
#endif

==> ws-v3.93.2-src.tar.gz: ws-v3.93-2/include/WSCgripHand.h <==
//
// Copyright (C) 1999-2006 WideStudio/MWT Project Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

#ifndef WSCGRIPHAND_H
#define WSCGRIPHAND_H

#include <WScom.h>
#include <WSCform.h>
class WSDprivateTimer;

class WSCgripHand :public WSCform{

  protected:
    WSDprivateTimer* _update_timer;

    WSDLEX32 static void _grip_hand_update_proc(void*);

    WSDLEX32 long _device_initialize();
  public:
    WSDLEX32 WSCgripHand(WSCbase*,char*);
    WSDLEX32 virtual ~WSCgripHand();
    WSDLEX32 virtual long getObjectType();

    WSDLEX32 virtual void onMousePress(WSCpoint*);
    WSDLEX32 virtual void onMouseRelease(WSCpoint*);

    WSMFguiClassDef(WSCgripHand,WSCform);
};
extern WSDLEX WSCbase* WSGFgetNewGripHand(WSCbase* parent);
#endif
